@@ -1,69 +1,44 @@
 #!/usr/bin/perl
-# distribution boxbackup-0.11.1 (svn version: 2821_2827)
-# Box Backup, http://www.boxbackup.org/
-# 
-# Copyright (c) 2003-2010, Ben Summers and contributors.
-# All rights reserved.
-# 
-# Note that this project uses mixed licensing. Any file with this license
-# attached, or where the code LICENSE-DUAL appears on the first line, falls
-# under this license. See the file COPYING.txt for more information.
-# 
-# This file is dual licensed. You may use and distribute it providing that you
-# comply EITHER with the terms of the BSD license, OR the GPL license. It is
-# not necessary to comply with both licenses, only one.
-# 
-# The BSD license option follows:
-# 
+# distribution boxbackup-0.10 (svn version: 494)
+#  
+# Copyright (c) 2003 - 2006
+#      Ben Summers and contributors.  All rights reserved.
+#  
 # Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-# 
+# modification, are permitted provided that the following conditions
+# are met:
 # 1. Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
-# 
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
+# 3. All use of this software and associated advertising materials must 
+#    display the following acknowledgment:
+#        This product includes software developed by Ben Summers.
+# 4. The names of the Authors may not be used to endorse or promote
+#    products derived from this software without specific prior written
+#    permission.
+# 
+# [Where legally impermissible the Authors do not disclaim liability for 
+# direct physical injury or death caused solely by defects in the software 
+# unless it is modified by a third party.]
+# 
+# THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
+# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT,
+# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+#  
+#  
 #  
-# 3. Neither the name of the Box Backup nor the names of its contributors may
-#    be used to endorse or promote products derived from this software without
-#    specific prior written permission.
-# 
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE FOR ANY
-# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-# 
-# [http://en.wikipedia.org/wiki/BSD_licenses#3-clause_license_.28.22New_BSD_License.22.29]
-# 
-# The GPL license option follows:
-# 
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-# 
-# [http://www.gnu.org/licenses/old-licenses/gpl-2.0.html#SEC4]
 use strict;
 
-use lib "../../infrastructure";
-use BoxPlatform;
-
 # Make protocol C++ classes from a protocol description file
 
 # built in type info (values are is basic type, C++ typename)
@@ -238,9 +213,6 @@ print CPP <<__E;
 // Auto-generated file -- do not edit
 
 #include "Box.h"
-
-#include <sstream>
-
 #include "$h_filename"
 #include "IOStream.h"
 
@@ -336,7 +308,7 @@ __E
 
 if($derive_objects_from ne 'ProtocolObject')
 {	
-	# output a definition for the protocol object derived class
+	# output a definition for the protocol object derviced class
 	print H <<__E;
 class ${protocol_name}ProtocolServer;
 	
@@ -401,7 +373,6 @@ __E
 	if(obj_is_type($cmd,'IsError'))
 	{
 		print H "\tbool IsError(int &rTypeOut, int &rSubTypeOut) const;\n";
-		print H "\tstd::string GetMessage() const;\n";
 	}
 	if($type eq 'Server' && obj_is_type($cmd, 'Command'))
 	{
@@ -562,49 +533,26 @@ bool ${class}IsError(int &rTypeOut, int &rSubTypeOut) const
 	rSubTypeOut = m$mem_subtype;
 	return true;
 }
-std::string ${class}GetMessage() const
-{
-	switch(m$mem_subtype)
-	{
-__E
-		foreach my $const (@{$cmd_constants{$cmd}})
-		{
-			next unless $const =~ /^Err_(.*)/;
-			my $shortname = $1;
-			$const =~ s/ = .*//;
-			print CPP <<__E;
-		case $const: return "$shortname";
-__E
-		}
-		print CPP <<__E;
-		default:
-			std::ostringstream out;
-			out << "Unknown subtype " << m$mem_subtype;
-			return out.str();
-	}
-}
 __E
 	}
 
 	if($implement_syslog)
 	{
-		my ($log) = make_log_strings_framework($cmd);
+		my ($format,$args) = make_log_strings($cmd);
 		print CPP <<__E;
 void ${class}LogSysLog(const char *Action) const
 {
-	BOX_TRACE($log);
+	::syslog(LOG_INFO,"%s $format",Action$args);
 }
 __E
 	}
 	if($implement_filelog)
 	{
-		my ($log) = make_log_strings_framework($cmd);
+		my ($format,$args) = make_log_strings($cmd);
 		print CPP <<__E;
 void ${class}LogFile(const char *Action, FILE *File) const
 {
-	std::ostringstream oss;
-	oss << $log;
-	::fprintf(File, "%s\\n", oss.str().c_str());
+	::fprintf(File,"%s $format\\n",Action$args);
 	::fflush(File);
 }
 __E
@@ -707,16 +655,16 @@ protected:
 
 __E
 
-my $constructor_extra = '';
-$constructor_extra .= ', mLogToSysLog(false)' if $implement_syslog;
-$constructor_extra .= ', mLogToFile(0)' if $implement_filelog;
+my $construtor_extra = '';
+$construtor_extra .= ', mLogToSysLog(false)' if $implement_syslog;
+$construtor_extra .= ', mLogToFile(0)' if $implement_filelog;
 
 my $destructor_extra = ($type eq 'Server')?"\n\tDeleteStreamsToSend();":'';
 
 my $prefix = $classname_base.'::';
 print CPP <<__E;
 $prefix$classname_base(IOStream &rStream)
-	: Protocol(rStream)$constructor_extra
+	: Protocol(rStream)$construtor_extra
 {
 }
 $prefix~$classname_base()
@@ -748,7 +696,7 @@ print CPP <<__E;
 	}
 }
 __E
-# write receive and send functions
+# write receieve and send functions
 print CPP <<__E;
 std::auto_ptr<$derive_objects_from> ${prefix}Receive()
 {
@@ -821,9 +769,51 @@ void ${prefix}DoServer($context_class &rContext)
 		// Get an object from the conversation
 		std::auto_ptr<${derive_objects_from}> pobj(Receive());
 
+__E
+	if($implement_syslog)
+	{
+		print CPP <<__E;
+		if(mLogToSysLog)
+		{
+			pobj->LogSysLog("Receive");
+		}
+__E
+	}
+	if($implement_filelog)
+	{
+		print CPP <<__E;
+		if(mLogToFile != 0)
+		{
+			pobj->LogFile("Receive", mLogToFile);
+		}
+__E
+	}
+	print CPP <<__E;
+
 		// Run the command
 		std::auto_ptr<${derive_objects_from}> preply((${derive_objects_from}*)(pobj->DoCommand(*this, rContext).release()));
 		
+__E
+	if($implement_syslog)
+	{
+		print CPP <<__E;
+		if(mLogToSysLog)
+		{
+			preply->LogSysLog("Send");
+		}
+__E
+	}
+	if($implement_filelog)
+	{
+		print CPP <<__E;
+		if(mLogToFile != 0)
+		{
+			preply->LogFile("Send", mLogToFile);
+		}
+__E
+	}
+	print CPP <<__E;
+
 		// Send the reply
 		Send(*(preply.get()));
 
@@ -869,57 +859,13 @@ if($implement_filelog || $implement_syslog)
 
 	if($implement_syslog)
 	{
-		$fR .= <<__E;
-	if(mLogToSysLog)
-	{
-		if(Size==Protocol::ProtocolStream_SizeUncertain)
-		{
-			BOX_TRACE("Receiving stream, size uncertain");
-		}
-		else
-		{
-			BOX_TRACE("Receiving stream, size " << Size);
-		}
+		$fR .= qq~\tif(mLogToSysLog) { ::syslog(LOG_INFO, (Size==Protocol::ProtocolStream_SizeUncertain)?"Receiving stream, size uncertain":"Receiving stream, size %d", Size); }\n~;
+		$fS .= qq~\tif(mLogToSysLog) { ::syslog(LOG_INFO, (Size==Protocol::ProtocolStream_SizeUncertain)?"Sending stream, size uncertain":"Sending stream, size %d", Size); }\n~;
 	}
-__E
-		
-		$fS .= <<__E;
-	if(mLogToSysLog)
-	{
-		if(Size==Protocol::ProtocolStream_SizeUncertain)
-		{
-			BOX_TRACE("Sending stream, size uncertain");
-		}
-		else
-		{
-			BOX_TRACE("Sending stream, size " << Size);
-		}
-	}
-__E
-	}
-
 	if($implement_filelog)
 	{
-		$fR .= <<__E;
-	if(mLogToFile)
-	{
-		::fprintf(mLogToFile,
-			(Size==Protocol::ProtocolStream_SizeUncertain)
-			?"Receiving stream, size uncertain\\n"
-			:"Receiving stream, size %d\\n", Size);
-		::fflush(mLogToFile);
-	}
-__E
-		$fS .= <<__E;
-	if(mLogToFile)
-	{
-		::fprintf(mLogToFile,
-			(Size==Protocol::ProtocolStream_SizeUncertain)
-			?"Sending stream, size uncertain\\n"
-			:"Sending stream, size %d\\n", Size);
-		::fflush(mLogToFile);
-	}
-__E
+		$fR .= qq~\tif(mLogToFile) { ::fprintf(mLogToFile, (Size==Protocol::ProtocolStream_SizeUncertain)?"Receiving stream, size uncertain":"Receiving stream, size %d\\n", Size); ::fflush(mLogToFile); }\n~;
+		$fS .= qq~\tif(mLogToFile) { ::fprintf(mLogToFile, (Size==Protocol::ProtocolStream_SizeUncertain)?"Sending stream, size uncertain":"Sending stream, size %d\\n", Size); ::fflush(mLogToFile); }\n~;
 	}
 
 	print CPP <<__E;
@@ -977,15 +923,11 @@ std::auto_ptr<$classname_base$reply> ${classname_base}::Query(const $classname_b
 		if(preply->IsError(type, subType))
 		{
 			SetError(type, subType);
-			BOX_WARNING("$cmd command failed: received error " <<
-				((${classname_base}Error&)*preply).GetMessage());
+			TRACE2("Protocol: Error received %d/%d\\n", type, subType);
 		}
 		else
 		{
 			SetError(Protocol::UnknownError, Protocol::UnknownError);
-			BOX_WARNING("$cmd command failed: received "
-				"unexpected response type " <<
-				preply->GetType());
 		}
 		
 		// Throw an exception
@@ -1077,15 +1019,8 @@ sub make_log_strings
 		{
 			# need to translate it
 			my ($format,$arg) = @{$log_display_types{$ty}};
-			$arg =~ s/VAR/m$nm/g;
-
-			if ($format eq "0x%llx" and $target_windows)
-			{
-				$format = "0x%I64x";
-				$arg = "(uint64_t)$arg";
-			}
-
 			push @str,$format;
+			$arg =~ s/VAR/m$nm/g;
 			push @arg,$arg;
 		}
 		else
@@ -1097,57 +1032,4 @@ sub make_log_strings
 	return ($cmd.'('.join(',',@str).')', join(',','',@arg));
 }
 
-sub make_log_strings_framework
-{
-	my ($cmd) = @_;
-
-	my @args;
-
-	for(my $x = 0; $x < $#{$cmd_contents{$cmd}}; $x+=2)
-	{
-		my ($ty,$nm) = (${$cmd_contents{$cmd}}[$x], ${$cmd_contents{$cmd}}[$x+1]);
-		
-		if(exists $log_display_types{$ty})
-		{
-			# need to translate it
-			my ($format,$arg) = @{$log_display_types{$ty}};
-			$arg =~ s/VAR/m$nm/g;
-
-			if ($format eq '\\"%s\\"')
-			{
-				$arg = "\"\\\"\" << $arg << \"\\\"\"";
-			}
-			elsif ($format =~ m'x$')
-			{
-				# my $width = 0;
-				# $ty =~ /^int(\d+)$/ and $width = $1 / 4;
-				$arg = 	"($arg == 0 ? \"0x\" : \"\") " .
-					"<< std::hex " .
-					"<< std::showbase " .
-					# "<< std::setw($width) " .
-					# "<< std::setfill('0') " .
-					# "<< std::internal " .
-					"<< $arg " .
-					"<< std::dec";
-			}
-
-			push @args, $arg;
-		}
-		else
-		{
-			# is opaque
-			push @args, '"OPAQUE"';
-		}
-	}
-
-	my $log_cmd = "Action << \" $cmd(\" ";
-	foreach my $arg (@args)
-	{
-		$arg = "<< $arg ";
-	}
-	$log_cmd .= join('<< "," ',@args);
-	$log_cmd .= '<< ")"';
-	return $log_cmd;
-}
-
 
